# CK2 Suite

A collection of tools to mod Crusader Kings 2

## [Suvorov](suvorov)

Suvorov is an expanded scripting language to make mod creation quicker and reduce maintenance work. It features:

* More structured mod directory
* Some meta-scripting logic and templating with the inclusion of custom data
* Simplification of common tasks with heavy boilerplate code

## [Stapomog](stapomog)

Stapomog is a generator for static portrait mods. It allows the user to simply gather desired images in one place and handles cropping, resizing, format conversion, sprite combination as well as all the boilerplate code for gfx definitions for them.

## [Bierstadt](bierstadt)

Bierstadt is a library and command line tool to handle CK2 graphics.
